"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const download = require("download-git-repo");
const fs = require("fs");
const lodash_1 = require("lodash");
const sortPackageJson = require("sort-package-json");
const Generator = require("yeoman-generator");
const yosay = require("yosay");
module.exports = class extends Generator {
    constructor(args, opts) {
        super(args, opts);
    }
    initializing() {
        this.log(yosay('Start up a new NestJS Project!'));
        download('teamhive/nestjs-seed', `${__dirname}/templates`, err => {
            if (err) {
                console.error('There was an issue downloading the latest template files. (teamhive/nestjs-seed)', err);
                process.exit();
            }
            const seedPackage = require(`${__dirname}/templates/package.json`);
            const generatorPackage = require(`${__dirname}/_package.json`);
            const combinedPackage = Object.assign({}, seedPackage, generatorPackage);
            const sortedPackage = sortPackageJson(combinedPackage);
            fs.writeFileSync(`${__dirname}/templates/package.json`, JSON.stringify(sortedPackage, null, 4));
            fs.copyFileSync(`${__dirname}/_README.md`, `${__dirname}/templates/README.md`);
        });
    }
    prompting() {
        return __awaiter(this, void 0, void 0, function* () {
            this.answers = yield this.prompt([{
                    type: 'input',
                    name: 'appname',
                    message: 'Package name',
                    default: this.appname
                }, {
                    type: 'input',
                    name: 'description',
                    message: 'Package description'
                }, {
                    type: 'input',
                    name: 'gitUser',
                    message: 'GitHub user or organization',
                    default: 'TeamHive'
                }, {
                    type: 'input',
                    name: 'authorName',
                    message: 'Author name'
                }, {
                    type: 'input',
                    name: 'authorUsername',
                    message: 'Author username'
                }]);
        });
    }
    writing() {
        this.fs.copyTpl(this.templatePath('**'), this.destinationPath(), this.replacements(), {}, { globOptions: { dot: true } });
    }
    install() {
        this.installDependencies({
            npm: true,
            bower: false
        });
    }
    replacements() {
        return {
            moduleName: lodash_1.kebabCase(this.answers.appname),
            description: this.answers.description,
            authorName: this.answers.authorName,
            authorUsername: this.answers.authorUsername,
            gitUser: this.answers.gitUser
        };
    }
};
